@@ -93,6 +93,7 @@ pub struct Function {
   pub return_type: String,
   pub error_type: String,
   pub namespace: String,
+  pub disable_logging: bool,
   pub output: String,
   pub dart_outer_params: String,
   pub dart_transforms: String,
@@ -413,6 +414,7 @@ impl<'a> Membrane {
 
       let extra_deps = r#"
   ffi: ^1.1.2
+  logging: ^1.0.2
 
 dev_dependencies:
   ffigen: ^4.1.0
@@ -506,14 +508,27 @@ int32_t membrane_cancel_membrane_task(const TaskHandle *task_handle);
 // Generated by `membrane`
 import 'dart:ffi';
 import 'dart:io' show Platform;
+import 'package:logging/logging.dart';
 
 import './ffi_bindings.dart' as ffi_bindings;
 
 DynamicLibrary _open() {{
-  if (Platform.isLinux) return DynamicLibrary.open('{lib}.so');
-  if (Platform.isAndroid) return DynamicLibrary.open('{lib}.so');
-  if (Platform.isIOS) return DynamicLibrary.executable();
-  if (Platform.isMacOS) return DynamicLibrary.open('{lib}.dylib');
+  if (Platform.isLinux) {{
+    Logger('membrane').info('Opening native library {lib}.so');
+    return DynamicLibrary.open('{lib}.so');
+  }}
+  if (Platform.isAndroid) {{
+    Logger('membrane').info('Opening native library {lib}.so');
+    return DynamicLibrary.open('{lib}.so');
+  }}
+  if (Platform.isIOS) {{
+    Logger('membrane').info('Creating dynamic library {lib}');
+    return DynamicLibrary.executable();
+  }}
+  if (Platform.isMacOS) {{
+    Logger('membrane').info('Opening native library {lib}.dylib');
+    return DynamicLibrary.open('{lib}.dylib');
+  }}
   throw UnsupportedError('This platform is not supported.');
 }}
 
@@ -526,12 +541,14 @@ typedef _StoreDartPostCobjectDart = void Function(
 
 _load() {{
   final dl = _open();
+  Logger('membrane').info('Initializing FFI bindings');
   final bindings = ffi_bindings.NativeLibrary(dl);
   final storeDartPostCobject =
       dl.lookupFunction<_StoreDartPostCobjectC, _StoreDartPostCobjectDart>(
     'store_dart_post_cobject',
   );
 
+  Logger('membrane').fine('Initializing Dart_PostCObject');
   storeDartPostCobject(NativeApi.postCObject);
 
   return bindings;
@@ -576,6 +593,7 @@ import 'dart:ffi';
 import 'dart:isolate' show ReceivePort;
 import 'dart:typed_data';
 import 'package:ffi/ffi.dart';
+import 'package:logging/logging.dart';
 import 'package:meta/meta.dart';
 
 import './src/loader.dart' as loader;
@@ -585,6 +603,7 @@ import './src/{ns}/{ns}.dart';
 export './src/{ns}/{ns}.dart' hide TraitHelpers;
 
 final _bindings = loader.bindings;
+final _loggingDisabled = bool.fromEnvironment('MEMBRANE_DISABLE_LOGS');
 
 @immutable
 class {class_name}ApiError implements Exception {{
@@ -594,6 +613,7 @@ class {class_name}ApiError implements Exception {{
 
 @immutable
 class {class_name}Api {{
+  static final _log = Logger('membrane');
   const {class_name}Api();
 "#,
       ns = &namespace,
@@ -662,26 +682,38 @@ impl Function {
 
   pub fn body(&mut self, namespace: &str) -> &mut Self {
     self.output += format!(
-      r#" {{
+      r#" {{{disable_logging}
     final List<Pointer> _toFree = [];{fn_transforms}
     final _port = ReceivePort()..timeout(const Duration(milliseconds: 1000));
 
     Pointer<Int32>? _taskHandle;
     try {{
+      if (!_loggingDisabled) {{
+        _log.fine('Calling Rust `{fn_name}` via C `{extern_c_fn_name}`');
+      }}
       _taskHandle = _bindings.{extern_c_fn_name}(_port.sendPort.nativePort{dart_inner_args});
       if (_taskHandle == null) {{
         throw {class_name}ApiError('Call to C failed');
       }}
     }} finally {{
       _toFree.forEach((ptr) => calloc.free(ptr));
+      if (!_loggingDisabled) {{
+        _log.fine('Freed arguments to `{extern_c_fn_name}`');
+      }}
     }}
 "#,
+      disable_logging = if self.disable_logging {
+        "final _loggingDisabled = true;"
+      } else {
+        ""
+      },
       fn_transforms = if self.dart_transforms.is_empty() {
         String::new()
       } else {
         "\n    ".to_string() + &self.dart_transforms + ";"
       },
       extern_c_fn_name = self.extern_c_fn_name,
+      fn_name = self.fn_name,
       dart_inner_args = if self.dart_inner_args.is_empty() {
         String::new()
       } else {
@@ -704,6 +736,9 @@ impl Function {
         r#"
     try {{
       yield* _port.map((input) {{
+        if (!_loggingDisabled) {{
+          _log.fine('Deserializing data from {fn_name}');
+        }}
         final deserializer = BincodeDeserializer(input as Uint8List);
         if (deserializer.deserializeBool()) {{
           return {return_de};
@@ -717,12 +752,16 @@ impl Function {
     }}"#,
         return_de = self.deserializer(&self.return_type, enum_tracer_registry, config),
         error_de = self.deserializer(&self.error_type, enum_tracer_registry, config),
-        class_name = namespace.to_camel_case()
+        class_name = namespace.to_camel_case(),
+        fn_name = self.fn_name
       )
     } else {
       format!(
         r#"
     try {{
+      if (!_loggingDisabled) {{
+        _log.fine('Deserializing data from {fn_name}');
+      }}
       final deserializer = BincodeDeserializer(await _port.first as Uint8List);
       if (deserializer.deserializeBool()) {{
         return {return_de};
@@ -735,7 +774,8 @@ impl Function {
     }}"#,
         return_de = self.deserializer(&self.return_type, enum_tracer_registry, config),
         error_de = self.deserializer(&self.error_type, enum_tracer_registry, config),
-        class_name = namespace.to_camel_case()
+        class_name = namespace.to_camel_case(),
+        fn_name = self.fn_name
       )
     }
     .as_str();
